@@ -1,4 +1,4 @@
-// Copyright © 2016-2020 Thomas Nagler and Thibault Vatter
+// Copyright © 2016-2022 Thomas Nagler and Thibault Vatter
 //
 // This file is part of the vinecopulib library and licensed under the terms of
 // the MIT license. For a copy, see the LICENSE file in the root directory of
@@ -39,7 +39,9 @@ protected:
            double,
            const Eigen::VectorXd& weights);
 
-  double get_npars();
+  double get_npars() const;
+
+  void set_npars(const double& npars);
 
   virtual Eigen::VectorXd get_start_parameters(const double tau) = 0;
 
